summaryrefslogtreecommitdiff
path: root/sal/test/bootstrap.pl
diff options
context:
space:
mode:
authorKay Ramme <kr@openoffice.org>2001-11-01 15:44:07 +0000
committerKay Ramme <kr@openoffice.org>2001-11-01 15:44:07 +0000
commitcde3f5e303b628dc170e1642fbc3076a48c81ae7 (patch)
treedfbdbfeb609a6ec6379f9f986502249655c258ac /sal/test/bootstrap.pl
parent5972a1fa42f275329c2c68b9b9867a1b8cd019d2 (diff)
added tests for default and ini expansion (#91782#)
Diffstat (limited to 'sal/test/bootstrap.pl')
-rwxr-xr-xsal/test/bootstrap.pl37
1 files changed, 25 insertions, 12 deletions
diff --git a/sal/test/bootstrap.pl b/sal/test/bootstrap.pl
index 101e3169d137..2c4ca939f723 100755
--- a/sal/test/bootstrap.pl
+++ b/sal/test/bootstrap.pl
@@ -5,9 +5,9 @@ eval 'exec perl -wS $0 ${1+"$@"}'
#
# $RCSfile: bootstrap.pl,v $
#
-# $Revision: 1.3 $
+# $Revision: 1.4 $
#
-# last change: $Author: kr $ $Date: 2001-10-11 13:14:37 $
+# last change: $Author: kr $ $Date: 2001-11-01 16:44:07 $
#
# The Contents of this file are made available subject to the terms of
# either of the following licenses
@@ -177,15 +177,20 @@ if (!$rc) {
delete $ENV{MYBOOTSTRAPTESTVALUE};
-$rc = system "./testbootstrap", "default", "-env:INIFILENAME=";
+$rc = system "./testbootstrap", "defaultvalue", "-env:INIFILENAME=", "-env:Default=defaultvalue";
if (!$rc) {
- $comment = $comment . "exe custom ini test 2 not passed\n";
+ $comment = $comment . "default test from parameter not passed\n";
$state = 0;
}
-$rc = system "./testbootstrap", "default", "-env:MYBOOTSTRAPTESTVALUE2=1", "-env:INIFILENAME=";
+if ($ENV{GUI} eq "WNT") {
+ $rc = system "./testbootstrap", "defaultValue", "-env:iniName=default.ini", "-env:INIFILENAME=";
+}
+else {
+ $rc = system "./testbootstrap", "defaultValue", "-env:iniName=defaultrc", "-env:INIFILENAME=";
+}
if (!$rc) {
- $comment = $comment . "exe custom ini test 3 not passed\n";
+ $comment = $comment . "default test from custom ini not passed\n";
$state = 0;
}
@@ -215,15 +220,23 @@ if (!$rc) {
# simple ini access
$rc = system "./testbootstrap",
- "TheKeysValue",
- '-env:MYBOOTSTRAPTESTVALUE=${./bootstraptest.ini:TheSection:TheKey}';
+ "TheIniKeysValue",
+ '-env:MYBOOTSTRAPTESTVALUE=${./bootstraptest.ini:TheIniKey}';
if (!$rc) {
$comment = $comment . "simple macro ini access test not passed\n";
$state = 0;
}
+# simple profile access
+$rc = system "./testbootstrap",
+ "TheKeysValue",
+ '-env:MYBOOTSTRAPTESTVALUE=${./bootstraptest.ini:TheSection:TheKey}';
+if (!$rc) {
+ $comment = $comment . "simple macro profile access test not passed\n";
+ $state = 0;
+}
-# ini access with simple macro expansion
+# profile access with simple macro expansion
$rc = system "./testbootstrap",
"TheKeysValue",
"-env:ININAME=./bootstraptest.ini",
@@ -231,17 +244,17 @@ $rc = system "./testbootstrap",
"-env:KEYNAME=TheKey",
'-env:MYBOOTSTRAPTESTVALUE=${$ININAME:$SECTIONNAME:$KEYNAME}';
if (!$rc) {
- $comment = $comment . "ini access with simple macro expansion test not passed\n";
+ $comment = $comment . "profile access with simple macro expansion test not passed\n";
$state = 0;
}
# ini access with complex macro expansion
$rc = system "./testbootstrap",
"TheKeysValue",
"-env:ININAME=./bootstraptest.ini",
'-env:MYBOOTSTRAPTESTVALUE=${$ININAME:${$ININAME:SecondSection:IndirectSection}:${$ININAME:SecondSection:IndirectKey}}';
if (!$rc) {
- $comment = $comment . "ini access with complex macro expansion test not passed\n";
+ $comment = $comment . "profile access with complex macro expansion test not passed\n";
$state = 0;
}
@@ -231,17 +244,17 @@ $rc = system "./testbootstrap",
$state = 0;
}
-# ini access with complex macro expansion
+# profile access with complex macro expansion
$rc = system "./testbootstrap",
"TheKeysValue",